@@ -9,7 +9,7 @@
 #ifndef SRC_CACHE_CACHE_MAP_H_
 #define SRC_CACHE_CACHE_MAP_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
