@@ -10,7 +10,7 @@
 #ifndef SRC_CACHE_COMMON_FLAT_READER_H_
 #define SRC_CACHE_COMMON_FLAT_READER_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <fstream>
 #include <string>
@@ -29,7 +29,7 @@ class FlatReader : public BasicReader {
 		explicit FlatReader(BasicCache *cache) : BasicReader(cache) {
 		}
 
-		ATTRIBUTE_NONNULL_ void get_keywords_slot_iuse_restrict(const std::string& filename, std::string *eapi, std::string *keywords, std::string *slotname, std::string *iuse, std::string *required_use, std::string *restr, std::string *props, Depend *dep) OVERRIDE;
+		ATTRIBUTE_NONNULL_ void get_keywords_slot_iuse_restrict(const std::string& filename, std::string *eapi, std::string *keywords, std::string *slotname, std::string *iuse, std::string *required_use, std::string *restr, std::string *props, Depend *dep, std::string *src_uri) OVERRIDE;
 		ATTRIBUTE_NONNULL_ void read_file(const std::string& filename, Package *pkg) OVERRIDE;
 
 	private:
