@@ -8,7 +8,7 @@
 #ifndef SRC_CACHE_COMMON_READER_H_
 #define SRC_CACHE_COMMON_READER_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <ctime>
 
@@ -44,7 +44,7 @@ class BasicReader {
 			return false;
 		}
 
-		ATTRIBUTE_NONNULL_ virtual void get_keywords_slot_iuse_restrict(const std::string& filename, std::string *eapi, std::string *keywords, std::string *slotname, std::string *iuse, std::string *required_use, std::string *restr, std::string *props, Depend *dep) = 0;
+		ATTRIBUTE_NONNULL_ virtual void get_keywords_slot_iuse_restrict(const std::string& filename, std::string *eapi, std::string *keywords, std::string *slotname, std::string *iuse, std::string *required_use, std::string *restr, std::string *props, Depend *dep, std::string *src_uri) = 0;
 
 		ATTRIBUTE_NONNULL_ virtual void read_file(const std::string& filename, Package *pkg) = 0;
 
