@@ -10,7 +10,7 @@
 #ifndef SRC_CACHE_COMMON_SELECTORS_H_
 #define SRC_CACHE_COMMON_SELECTORS_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
