@@ -7,7 +7,7 @@
 //   Emil Beinroth <emilbeinroth@gmx.net>
 //   Martin Väth <martin@mvath.de>
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <fnmatch.h>
 #include <sys/stat.h>
@@ -311,6 +311,7 @@ int run_eix_update(int argc, char *argv[]) {
 	}
 	Depend::use_depend = eixrc.getBool("DEP");
 	Version::use_required_use = eixrc.getBool("REQUIRED_USE");
+	ExtendedVersion::use_src_uri = eixrc.getBool("SRC_URI");
 	string eix_cachefile(eixrc["EIX_CACHEFILE"]); {
 	/* calculate defaults for use_{percentage,status} */
 		bool percentage_tty(false);
@@ -669,6 +670,11 @@ static bool update(const char *outputfile, CacheTable *cache_table, PortageSetti
 		Category *ci = c->second;
 		for(Category::iterator p(ci->begin());
 			likely(p != ci->end()); ++p) {
+			// We must set the reponame for proper masking in overlays
+			for(Package::iterator it(p->begin()); it != p->end(); ++it) {
+				const OverlayIdent& overlay(dbheader.getOverlay(it->overlay_key));
+				it->reponame = overlay.label;
+			}
 			portage_settings->setMasks(*p);
 			p->save_maskflags(Version::SAVEMASK_FILE);
 		}
