@@ -10,14 +10,16 @@
 #ifndef SRC_EIXTK_ASSERT_H_
 #define SRC_EIXTK_ASSERT_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 // check_includes: include "eixTk/assert.h"
 
 #ifndef NDEBUG
 
 #if defined(EIX_STATIC_ASSERT) || defined(EIX_PARANOIC_ASSERT)
-#include <cassert>
+#include <cassert>  // IWYU pragma: export
+
+#include "eixTk/diagnostics.h"
 #endif
 
 /**
@@ -26,14 +28,20 @@ are called exactly once
 **/
 
 #ifdef EIX_STATIC_ASSERT
-#define eix_assert_static(a) assert(a)
+#define eix_assert_static(a) \
+	WGNU_STATEMENT_EXPRESSION_OFF \
+	assert(a) \
+	WGNU_STATEMENT_EXPRESSION_ON
 #else
 #define eix_assert_static(a)
 #endif
 
 
 #ifdef EIX_PARANOIC_ASSERT
-#define eix_assert_paranoic(a) assert(a)
+#define eix_assert_paranoic(a) \
+	WGNU_STATEMENT_EXPRESSION_OFF \
+	assert(a) \
+	WGNU_STATEMENT_EXPRESSION_ON
 #else
 #define eix_assert_paranoic(a)
 #endif
