@@ -7,7 +7,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "eixTk/compare.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
