@@ -9,7 +9,7 @@
 #ifndef SRC_EIXTK_COMPARE_H_
 #define SRC_EIXTK_COMPARE_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
