@@ -8,15 +8,15 @@
 #ifndef SRC_EIXTK_NULL_H_
 #define SRC_EIXTK_NULL_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 // check_includes: include "eixTk/null.h"
 
 #ifdef HAVE_NULLPTR
-#define NULLPTR nullptr
+#define NULLPTR nullptr  // IWYU pragma: export
 #else
 #include <cstddef>
-#define NULLPTR NULL
+#define NULLPTR NULL  // IWYU pragma: export
 #endif
 
 #endif  // SRC_EIXTK_NULL_H_
