@@ -10,25 +10,31 @@
 #include "eixTk/stringutils.h"
 #include <config.h>  // IWYU pragma: keep
 
+#ifdef SUPPORT_SSE2
+#include <emmintrin.h>
+#endif
 #include <fnmatch.h>
-
-#include <locale>
+#include <sys/types.h>
 
 #include <cstdlib>
 #include <cstring>
 
 #include <algorithm>
+#include <locale>
 #include <string>
 #include <vector>
 
 #include "eixTk/attribute.h"
 #include "eixTk/diagnostics.h"
 #include "eixTk/dialect.h"
+#include "eixTk/eixint.h"
 #include "eixTk/formated.h"
 #include "eixTk/i18n.h"
 #include "eixTk/likely.h"
 #include "eixTk/null.h"
 #include "eixTk/stringtypes.h"
+#include "eixTk/unordered_set.h"
+
 
 using std::string;
 using std::vector;
@@ -287,9 +293,160 @@ static void erase_escapes(string *s, const char *at) {
 	}
 }
 
+eix::SignedBool natcmp(const string& a, const string& b) {
+	string::size_type i(0);
+	string::size_type j(0);
+	eix::SignedBool numerical(0);
+	eix::SignedBool zeroes(0);
+	bool number(false);
+	for(;; ++i, ++j) {
+		if(i == a.size()) {
+			if(j==b.size()) {
+				return (numerical == 0) ? zeroes : numerical;
+			} else {
+				return -1;
+			}
+		}
+		if(j == b.size()) {
+			return 1;
+		}
+		char c(a[i]);
+		char d(b[j]);
+		if(c == d) {
+			if(c == '0') {
+				continue;
+			}
+			if(my_isdigit(c)) {
+				if(!number) {
+					number = true;
+					numerical = zeroes = 0;
+				}
+				continue;
+			}
+			eix::SignedBool result((numerical == 0) ? zeroes : numerical);
+			if(result != 0) {
+				return result;
+			}
+			number = false;
+			numerical = zeroes = 0;
+			continue;
+		}
+		if(number) {
+			if(my_isdigit(c)) {
+				if(my_isdigit(d)) {
+					if(numerical == 0) {
+						numerical = ((c > d) ? 1 : -1);
+					}
+					continue;
+				}
+				return 1;
+			}
+			if(my_isdigit(d)) {
+				return -1;
+			}
+			eix::SignedBool result((numerical == 0) ? zeroes : numerical);
+			if(result != 0) {
+				return result;
+			}
+			return (c > d) ? 1 : -1;
+		}
+		if(c == '0') {
+			if(!my_isdigit(d)) {
+				return (c > d) ? 1 : -1;
+			}
+			for(;;) {
+				if(++i == a.size()) {
+					return -1;
+				}
+				c = a[i];
+				if(c == '0') {
+					continue;
+				}
+				if(c == d) {
+					numerical = 0;
+					zeroes = 1;
+					break;
+				}
+				if(isdigit(c)) {
+					numerical = (c > d) ? 1 : 0;
+					break;
+				}
+				return -1;
+			}
+			number = true;
+			continue;
+		}
+		if(d == '0') {
+			if(!my_isdigit(c)) {
+				return (c > d) ? 1 : -1;
+			}
+			for(;;) {
+				if(++j == b.size()) {
+					return 1;
+				}
+				d = b[j];
+				if(d == '0') {
+					continue;
+				}
+				if(c == d) {
+					numerical = 0;
+					zeroes = -1;
+					break;
+				}
+				if(isdigit(d)) {
+					numerical = (c > d) ? 1 : 0;
+					break;
+				}
+				return 1;
+			}
+			number = true;
+			continue;
+		}
+		if(my_isdigit(c) && my_isdigit(d)) {
+			zeroes = 0;
+			numerical = (c > d) ? 1 : -1;
+			number = true;
+			continue;
+		}
+		return (c > d) ? 1 : -1;
+	}
+}
+
+static string::size_type find_first_of(const string& str, const char *at, string::size_type pos, size_t at_len) {
+#ifdef SUPPORT_SSE2
+	const char *s = str.c_str();
+	const string::size_type str_size = str.size();
+
+	__v16qi at16 = {};
+	for(size_t i = 0; i < at_len; i++) {
+		at16[i] = at[i];
+	}
+
+	for(; pos < str_size; pos++) {
+		const char c = s[pos];
+
+		// Vectorized compare of 'c' with the leading 16 characters of 'at'
+		__v16qi c16 = {c, c, c, c, c, c, c, c, c, c, c, c, c, c, c, c};
+		if(_mm_movemask_epi8(c16 == at16) != 0) {
+			return pos;
+		}
+
+		for(size_t i = 16; i < at_len; i++) {
+			if(c == at[i]) {
+				return pos;
+			}
+		}
+	}
+	return string::npos;
+#else
+	return str.find_first_of(at, pos, at_len);
+#endif
+}
+
 template<typename T> inline static void split_string_template(T *vec, const string& str, bool handle_escape, const char *at, bool ignore_empty) {
+	const size_t at_len = std::strlen(at);
 	string::size_type last_pos(0), pos(0);
-	while((pos = str.find_first_of(at, pos)) != string::npos) {
+	while((pos = find_first_of(str, at, pos, at_len)) != string::npos) {
 		if(unlikely(handle_escape)) {
 			bool escaped(false);
 			string::size_type s(pos);
@@ -331,9 +488,11 @@ void split_string(WordSet *vec, const string& str, bool handle_escape, const cha
 	split_string_template<WordSet>(vec, str, handle_escape, at, ignore_empty);
 }
 
+#ifdef HAVE_UNORDERED_SET
 void split_string(WordUnorderedSet *vec, const string& str, bool handle_escape, const char *at, bool ignore_empty) {
 	split_string_template<WordUnorderedSet>(vec, str, handle_escape, at, ignore_empty);
 }
+#endif
 
 WordVec split_string(const string& str, bool handle_escape, const char *at, bool ignore_empty) {
 	WordVec vec;
