@@ -23,6 +23,7 @@
 
 #include "eixTk/attribute.h"
 #include "eixTk/dialect.h"
+#include "eixTk/eixint.h"
 #include "eixTk/likely.h"
 #include "eixTk/null.h"
 #include "eixTk/stringtypes.h"
@@ -186,6 +187,14 @@ inline static void escape_string(std::string *str) {
 	escape_string(str, spaces);
 }
 
+/**
+Returns -1, 0, 1, depending on whether a is < = > than b in natural order.
+Natural order means: ascii-order except for digits; sequences of digits are
+compared as numbers. Leading zeroes are ignored, but if numbers differ only
+by leading zeroes, the one with more leading zeroes is considered to be larger.
+**/
+eix::SignedBool natcmp(const std::string& a, const std::string& b);
+
 /**
 Split a string into multiple strings.
 @param vec Will contain the result. Actually the result is pushed_back
@@ -198,44 +207,46 @@ Split a string into multiple strings.
                      removing escapes for \\ or "at" symbols from result.
 **/
 ATTRIBUTE_NONNULL_ void split_string(WordVec *vec, const std::string& str, bool handle_escape, const char *at, bool ignore_empty);
-ATTRIBUTE_NONNULL_ void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at, bool ignore_empty);
-ATTRIBUTE_NONNULL_ void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at, bool ignore_empty);
 ATTRIBUTE_NONNULL_ inline static void split_string(WordVec *vec, const std::string& str, bool handle_escape, const char *at);
 inline static void split_string(WordVec *vec, const std::string& str, bool handle_escape, const char *at) {
 	split_string(vec, str, handle_escape, at, true);
 }
-ATTRIBUTE_NONNULL_ inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at);
-inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at) {
-	split_string(vec, str, handle_escape, at, true);
-}
-ATTRIBUTE_NONNULL_ inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at);
-inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at) {
-	split_string(vec, str, handle_escape, at, true);
-}
 ATTRIBUTE_NONNULL_ inline static void split_string(WordVec *vec, const std::string& str, bool handle_escape);
 inline static void split_string(WordVec *vec, const std::string& str, bool handle_escape) {
 	split_string(vec, str, handle_escape, spaces);
 }
-ATTRIBUTE_NONNULL_ inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape);
-inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape) {
-	split_string(vec, str, handle_escape, spaces);
-}
-ATTRIBUTE_NONNULL_ inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape);
-inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape) {
-	split_string(vec, str, handle_escape, spaces);
-}
 ATTRIBUTE_NONNULL_ inline static void split_string(WordVec *vec, const std::string& str);
 inline static void split_string(WordVec *vec, const std::string& str) {
 	split_string(vec, str, false);
 }
+ATTRIBUTE_NONNULL_ void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at, bool ignore_empty);
+ATTRIBUTE_NONNULL_ inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at);
+inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape, const char *at) {
+	split_string(vec, str, handle_escape, at, true);
+}
+ATTRIBUTE_NONNULL_ inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape);
+inline static void split_string(WordSet *vec, const std::string& str, bool handle_escape) {
+	split_string(vec, str, handle_escape, spaces);
+}
 ATTRIBUTE_NONNULL_ inline static void split_string(WordSet *vec, const std::string& str);
 inline static void split_string(WordSet *vec, const std::string& str) {
 	split_string(vec, str, false);
 }
+#ifdef HAVE_UNORDERED_SET
+ATTRIBUTE_NONNULL_ void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at, bool ignore_empty);
+ATTRIBUTE_NONNULL_ inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at);
+inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape, const char *at) {
+	split_string(vec, str, handle_escape, at, true);
+}
+ATTRIBUTE_NONNULL_ inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape);
+inline static void split_string(WordUnorderedSet *vec, const std::string& str, bool handle_escape) {
+	split_string(vec, str, handle_escape, spaces);
+}
 ATTRIBUTE_NONNULL_ inline static void split_string(WordUnorderedSet *vec, const std::string& str);
 inline static void split_string(WordUnorderedSet *vec, const std::string& str) {
 	split_string(vec, str, false);
 }
+#endif
 
 /**
 Check if slot contains a subslot and if yes, split it away.
@@ -484,7 +495,7 @@ template<typename T> inline static void push_back(std::vector<T> *v, const T& e)
 }
 #ifdef HAVE_MOVE
 template<typename T> inline static void push_back(std::vector<T> *v, T&& e) {
-	v->PUSH_BACK(e);
+	v->PUSH_BACK(MOVE(e));
 }
 #endif
 
@@ -496,7 +507,7 @@ template<typename T> inline static void push_back(std::set<T> *s, const T& e) {
 }
 #ifdef HAVE_MOVE
 template<typename T> inline static void push_back(std::set<T> *s, T&& e) {
-	s->INSERT(e);
+	s->INSERT(MOVE(e));
 }
 #endif
 
@@ -509,7 +520,7 @@ template<typename T> inline static void push_back(UNORDERED_SET<T> *s, const T&
 }
 #ifdef HAVE_MOVE
 template<typename T> inline static void push_back(UNORDERED_SET<T> *s, T&& e) {
-	s->INSERT(e);
+	s->INSERT(MOVE(e));
 }
 #endif
 #endif  // HAVE_UNORDERED_SET
