@@ -126,41 +126,40 @@ static bool pushback_lines_file(const char *file, LineVec *v, bool keep_empty, e
 	return false;
 }
 
-/**
-Files excluded for pushback_lines in recursive mode
-**/
-const char *pushback_lines_exclude[] = { "..", ".", "CVS", "RCS", "SCCS", NULLPTR };
-
 /**
 push_back every line of file or dir into v.
 **/
 bool pushback_lines(const char *file, LineVec *v, bool recursive, bool keep_empty, eix::SignedBool keep_comments, string *errtext) {
-	static int depth(0);
-	WordVec files;
-	string dir(file);
-	dir.append(1, '/');
-	if(recursive && pushback_files(dir, &files, pushback_lines_exclude, 3)) {
-		bool rvalue(true);
-		for(WordVec::const_iterator it(files.begin());
-			likely(it != files.end()); ++it) {
-			++depth;
-			if(depth == 100) {
-				if(errtext != NULLPTR) {
-					*errtext = eix::format(_("nesting level too deep in %s")) % dir;
-				}
-				return false;
-			}
-			if(unlikely(!pushback_lines(it->c_str(), v, true, keep_empty, keep_comments, errtext))) {
-				rvalue = false;
-			}
-			--depth;
-		}
-		return rvalue;
-	} else {
+	if(!recursive) {
 		return pushback_lines_file(file, v, keep_empty, keep_comments, errtext);
 	}
+	WordVec files;
+	bool rvalue(pushback_files_recurse(file, &files, true, errtext));
+	for(WordVec::const_iterator it(files.begin()); likely(it != files.end()); ++it) {
+		if(unlikely(!pushback_lines_file(it->c_str(), v, keep_empty, keep_comments, errtext))) {
+			rvalue = false;
+		}
+	}
+	return rvalue;
 }
 
+static bool is_only_type(const string &file, int only_type) {
+	if (only_type == 0) {
+		return true;
+	}
+	struct stat static_stat;
+	if(likely(stat(file.c_str(), &static_stat) == 0)) {
+		if (((only_type & 1) != 0)  && S_ISREG(static_stat.st_mode)) {
+			return true;
+		}
+		if (((only_type & 2) != 0) && S_ISDIR(static_stat.st_mode)) {
+			return true;
+		}
+	}
+	return false;
+}
+
+
 /**
 These variables and function are only supposed to be used from
 pushback_files. We cannot use a class here, because scandir wants a
@@ -169,10 +168,10 @@ pushback_files. We cannot use a class here, because scandir wants a
 static const char *const *pushback_files_exclude;
 static bool pushback_files_no_hidden;
 static size_t pushback_files_only_type;
-static const string *pushback_files_dir_path;  // defined if pushback_files_only_type is nonzero
+static string pushback_files_dir_path;  // defined if pushback_files_only_type is nonzero
 static int pushback_files_selector(SCANDIR_ARG3 dir_entry) {
 	// Empty names shouldn't occur. Just to be sure, we ignore them:
-	if(!((dir_entry->d_name)[0])) {
+	if((dir_entry->d_name)[0] == '\0') {
 		return 0;
 	}
 
@@ -187,7 +186,7 @@ static int pushback_files_selector(SCANDIR_ARG3 dir_entry) {
 			return 0;
 		}
 	}
-	if(pushback_files_exclude) {
+	if(pushback_files_exclude != NULLPTR) {
 		// Look if it's in exclude
 		for(const char *const *p(pushback_files_exclude); likely(*p != NULLPTR); ++p) {
 			if(unlikely(std::strcmp(*p, dir_entry->d_name) == 0)) {
@@ -195,44 +194,16 @@ static int pushback_files_selector(SCANDIR_ARG3 dir_entry) {
 			}
 		}
 	}
-	if(likely(pushback_files_only_type == 0)) {
-		return 1;
-	}
-	struct stat static_stat;
-	if(unlikely(stat(((*pushback_files_dir_path) + dir_entry->d_name).c_str(), &static_stat))) {
-		return 0;
-	}
-	if(pushback_files_only_type & 1) {
-		if(S_ISREG(static_stat.st_mode)) {
-			return 1;
-		}
-	}
-	if(pushback_files_only_type & 2) {
-		if(S_ISDIR(static_stat.st_mode)) {
-			return 1;
-		}
-	}
-	return 0;
+	return is_only_type(pushback_files_dir_path + dir_entry->d_name, pushback_files_only_type) ? 1 : 0;
 }
 
-/**
-List of files in directory.
-Pushed names of file in directory into string-vector if the don't match any
-char * in given exlude list.
-@param dir_path Path to directory
-@param into pointer to WordVec .. files get append here (with full path)
-@param exclude list of char * that don't need to be put into vector
-@param only_type: if 1: consider only ordinary files, if 2: consider only dirs, if 3: consider only files or dirs
-@param no_hidden ignore hidden files
-@param full_path return full pathnames
-@return true if everything is ok
-**/
 bool pushback_files(const string& dir_path, WordVec *into, const char *const exclude[], unsigned char only_type, bool no_hidden, bool full_path) {
 	pushback_files_exclude = exclude;
 	pushback_files_no_hidden = no_hidden;
 	pushback_files_only_type = only_type;
-	if(only_type) {
-		pushback_files_dir_path = &dir_path;
+	if(only_type != 0) {
+		pushback_files_dir_path.assign(dir_path);
+		pushback_files_dir_path.append(1, '/');
 	}
 	WordVec namelist;
 	if(!scandir_cc(dir_path, &namelist, pushback_files_selector)) {
@@ -249,6 +220,45 @@ bool pushback_files(const string& dir_path, WordVec *into, const char *const exc
 	return true;
 }
 
+/**
+Files excluded for recursive pushback_files
+**/
+const char *pushback_files_recurse_exclude[] = { "..", ".", "CVS", "RCS", "SCCS", NULLPTR };
+
+bool pushback_files_recurse(const string& dir_path, const string& subpath, int depth, WordVec *into, bool full_path, string *errtext) {
+	WordVec files;
+	if(pushback_files(dir_path, &files, pushback_files_exclude, 3, true, false)) {
+		string dir(dir_path);
+		dir.append(1, '/');
+		string subdir(subpath);
+		if (depth != 0) {
+			subdir.append(1, '/');
+		}
+		for(WordVec::const_iterator it(files.begin());
+			likely(it != files.end()); ++it) {
+			if(depth == 100) {
+				if(errtext != NULLPTR) {
+					*errtext = eix::format(_("nesting level too deep in %s")) % dir_path;
+				}
+				return false;
+			}
+			if(unlikely(!pushback_files_recurse(dir + (*it), subdir + (*it), depth + 1, into, full_path, errtext))) {
+				return false;
+			}
+		}
+		return true;
+	}
+	if ((depth == 0) && !is_only_type(dir_path, 1)) {
+		return true;
+	}
+	if (full_path) {
+		into->PUSH_BACK(MOVE(dir_path));
+	} else {
+		into->PUSH_BACK(MOVE(subpath));
+	}
+	return true;
+}
+
 void dump_version() {
 	eix::say() % PACKAGE_VERSION;
 	std::exit(EXIT_SUCCESS);
