@@ -1053,7 +1053,7 @@ bool VarsReader::read(const char *filename, string *errtext, bool noexist_ok, Wo
 		string dir(filename);
 		dir.append(1, '/');
 		WordVec files;
-		if(pushback_files(dir, &files, pushback_lines_exclude, 3)) {
+		if(pushback_files(dir, &files, pushback_files_recurse_exclude, 3, true, true)) {
 			for(WordVec::const_iterator file(files.begin());
 				likely(file != files.end()); ++file) {
 				if(!read(file->c_str(), errtext, false, sourced, false)) {
@@ -1160,7 +1160,7 @@ bool VarsReader::parse() {
 		if(f->second.empty()) {
 			f->second = it->second;
 		} else {
-			f->second = (it->second) + ' ' + (f->second);
+			f->second = (it->second) + '\n' + (f->second);
 		}
 	}
 	return ret;
