@@ -10,7 +10,7 @@
 #ifndef SRC_EIXRC_GLOBAL_H_
 #define SRC_EIXRC_GLOBAL_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include "eixTk/attribute.h"
 
