@@ -14,7 +14,7 @@
 // It collects common includes and macros for eixrc/global?.cc
 // It should be included *only* by these files!
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <cstdlib>
 
