@@ -18,6 +18,7 @@
 #include <map>
 #include <string>
 #include <utility>
+#include <vector>
 
 #include "eixTk/ansicolor.h"
 #include "eixTk/assert.h"
@@ -43,6 +44,7 @@
 using std::map;
 using std::pair;
 using std::string;
+using std::vector;
 
 ATTRIBUTE_NONNULL_ static Package *old_or_new(string *new_name, Package *older, Package *newer, const string& name);
 
@@ -85,11 +87,12 @@ PrintFormat::iuse_expand(OutputString *s, const IUseSet& iuse, bool coll, Handle
 		s->assign_smart(iuse.asString());
 		return;
 	}
-	typedef map<string, OutputString> ExpVars;
-	ExpVars expvars;
-	const IUseSet::IUseStd& iuse_std(iuse.asStd());
-	for(IUseSet::IUseStd::const_iterator it(iuse_std.begin());
-		it != iuse_std.end(); ++it) {
+	UNORDERED_MAP<string, OutputString> expvars;
+	typedef vector<string> ExpVarNames;
+	ExpVarNames expvarnames;
+	const IUseSet::IUseNaturalOrder iuse_ordered(iuse.asNaturalOrder());
+	for(IUseSet::IUseNaturalOrder::const_iterator it(iuse_ordered.begin());
+		it != iuse_ordered.end(); ++it) {
 		string var, expval;
 		const string& name(it->name());
 		if(portagesettings->use_expand(&var, &expval, name)) {
@@ -97,10 +100,12 @@ PrintFormat::iuse_expand(OutputString *s, const IUseSet& iuse, bool coll, Handle
 				continue;
 			}
 			OutputString& r(expvars[var]);
-			if(!r.empty()) {
+			if(r.empty()) {
+				expvarnames.push_back(var);
+			} else {
 				r.append_fast(' ');
 			}
-			const char *p(it->prefix());
+			const char *p(it->iuse().prefix());
 			if(p != NULLPTR) {
 				r.append_smart(p);
 			}
@@ -112,14 +117,14 @@ PrintFormat::iuse_expand(OutputString *s, const IUseSet& iuse, bool coll, Handle
 			s->append_smart(it->asString());
 		}
 	}
-	for(ExpVars::const_iterator it(expvars.begin()); it != expvars.end(); ++it) {
+	for(ExpVarNames::const_iterator it(expvarnames.begin()); it != expvarnames.end(); ++it) {
 		if(!s->empty()) {
 			s->append_fast(' ');
 		}
 		s->append(coll ? before_coll_start : before_iuse_start);
-		s->append_smart(it->first);
+		s->append_smart(*it);
 		s->append(coll ? before_coll_end : before_iuse_end);
-		s->append(it->second);
+		s->append(expvars[*it]);
 		s->append(coll ? after_coll : after_iuse);
 	}
 }
@@ -130,8 +135,9 @@ void PrintFormat::get_inst_use(OutputString *s, const Package& package, InstVers
 	}
 	OutputString add;
 	string expval;
-	typedef map<string, pair<OutputString, OutputString> > ExpVars;
-	ExpVars expvars;
+	map<string, pair<OutputString, OutputString> > expvars;
+	typedef vector<string> ExpVarNames;
+	ExpVarNames expvarnames;
 	for(WordVec::iterator it(i->inst_iuse.begin());
 		likely(it != i->inst_iuse.end()); ++it) {
 		string *value(&(*it));
@@ -150,6 +156,9 @@ void PrintFormat::get_inst_use(OutputString *s, const Package& package, InstVers
 				}
 				value = &expval;
 				pair<OutputString, OutputString>& r(expvars[var]);
+				if(r.first.empty() && r.second.empty()) {
+					expvarnames.push_back(var);
+				}
 				curr = (unset_list ? &(r.second) : &(r.first));
 			}
 		}
@@ -174,16 +183,17 @@ void PrintFormat::get_inst_use(OutputString *s, const Package& package, InstVers
 		}
 		s->append(add);
 	}
-	for(ExpVars::const_iterator it(expvars.begin()); it != expvars.end(); ++it) {
+	for(ExpVarNames::const_iterator it(expvarnames.begin()); it != expvarnames.end(); ++it) {
 		if(!s->empty()) {
 			s->append_fast(' ');
 		}
 		s->append(before_use_start);
-		s->append_smart(it->first);
+		s->append_smart(*it);
 		s->append(before_use_end);
-		const OutputString& f(it->second.first);
+		pair<OutputString, OutputString> &r(expvars[*it]);
+		const OutputString& f(r.first);
 		s->append(f);
-		const OutputString& t(it->second.second);
+		const OutputString& t(r.second);
 		if(!t.empty()) {
 			if(!f.empty()) {
 				s->append_fast(' ');
@@ -468,8 +478,11 @@ class Scanner {
 			prop_ver("virtual", &PrintFormat::VER_VIRTUAL);
 			prop_ver("isbinary", &PrintFormat::VER_ISBINARY);
 			prop_ver("istbz", &PrintFormat::VER_ISTBZ);
+			prop_ver("isgpkg", &PrintFormat::VER_ISGPKG);
 			prop_ver("ispak", &PrintFormat::VER_ISPAK);
+			prop_ver("ismultigpkg", &PrintFormat::VER_ISMULTIGPKG);
 			prop_ver("ismultipak", &PrintFormat::VER_ISMULTIPAK);
+			prop_ver("gpkgcount", &PrintFormat::VER_GPKGCOUNT);
 			prop_ver("pakcount", &PrintFormat::VER_PAKCOUNT);
 			prop_ver("restrict", &PrintFormat::VER_RESTRICT);
 			prop_ver("restrictfetch", &PrintFormat::VER_RESTRICTFETCH);
@@ -491,6 +504,7 @@ class Scanner {
 			prop_ver("haverdepend", &PrintFormat::VER_HAVERDEPEND);
 			prop_ver("havepdepend", &PrintFormat::VER_HAVEPDEPEND);
 			prop_ver("havebdepend", &PrintFormat::VER_HAVEBDEPEND);
+			prop_ver("haveidepend", &PrintFormat::VER_HAVEIDEPEND);
 			prop_ver("havedeps", &PrintFormat::VER_HAVEDEPS);
 			prop_ver("depend*", &PrintFormat::VER_DEPENDS);
 			prop_ver("depend", &PrintFormat::VER_DEPEND);
@@ -500,6 +514,8 @@ class Scanner {
 			prop_ver("pdepend", &PrintFormat::VER_PDEPEND);
 			prop_ver("bdepend*", &PrintFormat::VER_BDEPENDS);
 			prop_ver("bdepend", &PrintFormat::VER_BDEPEND);
+			prop_ver("idepend*", &PrintFormat::VER_IDEPENDS);
+			prop_ver("idepend", &PrintFormat::VER_IDEPEND);
 			prop_ver("ishardmasked", &PrintFormat::VER_ISHARDMASKED);
 			prop_ver("isprofilemasked", &PrintFormat::VER_ISPROFILEMASKED);
 			prop_ver("ismasked", &PrintFormat::VER_ISMASKED);
@@ -1339,18 +1355,37 @@ void PrintFormat::VER_ISTBZ(OutputString *s, Package *package) const {
 	}
 }
 
+void PrintFormat::VER_ISGPKG(OutputString *s, Package *package) const {
+	if(ver_version()->num_gpkg_pkg(portagesettings, package) != 0) {
+		s->set_one();
+	}
+}
+
 void PrintFormat::VER_ISPAK(OutputString *s, Package *package) const {
 	if(ver_version()->num_pak_pkg(portagesettings, package) != 0) {
 		s->set_one();
 	}
 }
 
+void PrintFormat::VER_ISMULTIGPKG(OutputString *s, Package *package) const {
+	if(ver_version()->num_gpkg_pkg(portagesettings, package) > 1) {
+		s->set_one();
+	}
+}
+
 void PrintFormat::VER_ISMULTIPAK(OutputString *s, Package *package) const {
 	if(ver_version()->num_pak_pkg(portagesettings, package) > 1) {
 		s->set_one();
 	}
 }
 
+void PrintFormat::VER_GPKGCOUNT(OutputString *s, Package *package) const {
+	ExtendedVersion::CountBinPkg count(ver_version()->num_gpkg_pkg(portagesettings, package));
+	if(count != 0) {
+		s->assign_fast(eix::format() % count);
+	}
+}
+
 void PrintFormat::VER_PAKCOUNT(OutputString *s, Package *package) const {
 	ExtendedVersion::CountBinPkg count(ver_version()->num_pak_pkg(portagesettings, package));
 	if(count != 0) {
@@ -1486,6 +1521,16 @@ void PrintFormat::VER_HAVEBDEPEND(OutputString *s, Package *package) const {
 	}
 }
 
+void PrintFormat::VER_HAVEIDEPEND(OutputString *s, Package *package) const {
+	if(version_variables->isinst) {
+		eix_assert_paranoic(header != NULLPTR);
+		vardb->readDepend(*package, version_variables->instver(), *header);
+	}
+	if(!ver_version()->depend.idepend_empty()) {
+		s->set_one();
+	}
+}
+
 void PrintFormat::VER_HAVEDEPS(OutputString *s, Package *package) const {
 	if(version_variables->isinst) {
 		eix_assert_paranoic(header != NULLPTR);
@@ -1560,6 +1605,22 @@ void PrintFormat::VER_BDEPEND(OutputString *s, Package *package) const {
 	s->assign_smart(ver_version()->depend.get_bdepend());
 }
 
+void PrintFormat::VER_IDEPENDS(OutputString *s, Package *package) const {
+	if(version_variables->isinst) {
+		eix_assert_paranoic(header != NULLPTR);
+		vardb->readDepend(*package, version_variables->instver(), *header);
+	}
+	s->assign_smart(ver_version()->depend.get_idepend_brief());
+}
+
+void PrintFormat::VER_IDEPEND(OutputString *s, Package *package) const {
+	if(version_variables->isinst) {
+		eix_assert_paranoic(header != NULLPTR);
+		vardb->readDepend(*package, version_variables->instver(), *header);
+	}
+	s->assign_smart(ver_version()->depend.get_idepend());
+}
+
 const MaskFlags *PrintFormat::ver_maskflags() const {
 	return ((unlikely(version_variables->isinst)) ?
 		NULLPTR : (&(version_variables->version()->maskflags)));
