@@ -10,7 +10,7 @@
 #ifndef SRC_OUTPUT_FORMATSTRING_PRINT_H_
 #define SRC_OUTPUT_FORMATSTRING_PRINT_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
