@@ -350,8 +350,11 @@ class PrintFormat {
 		ATTRIBUTE_NONNULL_ void VER_VIRTUAL(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_ISBINARY(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_ISTBZ(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_ISGPKG(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_ISPAK(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_ISMULTIGPKG(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_ISMULTIPAK(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_GPKGCOUNT(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_PAKCOUNT(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ const ExtendedVersion *ver_restrict(Package *package) const;
 		ATTRIBUTE_NONNULL_ void ver_restrict(OutputString *s, Package *package, ExtendedVersion::Restrict r) const;
@@ -376,6 +379,7 @@ class PrintFormat {
 		ATTRIBUTE_NONNULL_ void VER_HAVERDEPEND(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_HAVEPDEPEND(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_HAVEBDEPEND(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_HAVEIDEPEND(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_HAVEDEPS(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_DEPENDS(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_DEPEND(OutputString *s, Package *package) const;
@@ -385,6 +389,8 @@ class PrintFormat {
 		ATTRIBUTE_NONNULL_ void VER_PDEPEND(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_BDEPENDS(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_BDEPEND(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_IDEPENDS(OutputString *s, Package *package) const;
+		ATTRIBUTE_NONNULL_ void VER_IDEPEND(OutputString *s, Package *package) const;
 		ATTRIBUTE_PURE const MaskFlags *ver_maskflags() const;
 		ATTRIBUTE_NONNULL_ void VER_ISHARDMASKED(OutputString *s, Package *package) const;
 		ATTRIBUTE_NONNULL_ void VER_ISPROFILEMASKED(OutputString *s, Package *package) const;
