@@ -136,28 +136,47 @@ static CONSTEXPR const char *test_in_env_late[] = {
 	NULLPTR
 };
 
-void PortageSettings::override_by_env(const char *const *vars) {
+void PortageSettings::override_by_map(const char *const *vars, const WordIterateMap& varmap) {
 	for(const char *var(*vars); likely(var != NULLPTR); var = *(++vars)) {
-		const char *e(std::getenv(var));
-		if(e == NULLPTR)
-			continue;
-		if(!match_list(default_accumulating_keys, var)) {
-			(*this)[var] = e;
-			continue;
+		WordIterateMap::const_iterator it(varmap.find(var));
+		if(it != varmap.end()) {
+			override_by_value(var, it->second);
 		}
-		string& ref((*this)[var]);
-		if(ref.empty())
-			ref = e;
-		else
-			ref.append(string("\n") + e);
 	}
 }
 
-void PortageSettings::read_config(const string& name, const string& prefix) {
+void PortageSettings::override_by_env(const char *const *vars) {
+	for(const char *var(*vars); likely(var != NULLPTR); var = *(++vars)) {
+		override_by_value(var, std::getenv(var));
+	}
+}
+
+void PortageSettings::override_by_value(const char *var, const string& value) {
+	string& ref((*this)[var]);
+	if(ref.empty() || !match_list(default_accumulating_keys, var)) {
+		ref = value;
+	} else {
+		ref.append(string("\n") + value);
+	}
+}
+
+void PortageSettings::override_by_value(const char *var, const char *value) {
+	if(value == NULLPTR) {
+		return;
+	}
+	string& ref((*this)[var]);
+	if(ref.empty() || !match_list(default_accumulating_keys, var)) {
+		ref.assign(value);
+	} else {
+		ref.append(string("\n") + value);
+	}
+}
+
+void PortageSettings::read_config(const string& name, const string& prefix, WordIterateMap *vars) {
 	(*this)["EPREFIX"] = m_eprefix;
 	VarsReader configfile(VarsReader::SUBST_VARS|VarsReader::INTO_MAP|VarsReader::APPEND_VALUES|VarsReader::ALLOW_SOURCE|VarsReader::PORTAGE_ESCAPES|VarsReader::RECURSE);
 	configfile.accumulatingKeys(default_accumulating_keys);
-	configfile.useMap(this);
+	configfile.useMap(vars);
 	configfile.setPrefix(prefix);
 	string errtext;
 	if(unlikely(!configfile.read(name.c_str(), &errtext, true))) {
@@ -165,6 +184,140 @@ void PortageSettings::read_config(const string& name, const string& prefix) {
 	}
 }
 
+void PortageSettings::read_make_conf(const string& eprefixsource, WordIterateMap *vars) {
+	read_config(m_eprefixconf + MAKE_CONF_FILE, eprefixsource, vars);
+	read_config(m_eprefixconf + MAKE_CONF_FILE_NEW, eprefixsource, vars);
+}
+
+void PortageSettings::read_make_conf_early(const string& eprefixsource) {
+	WordIterateMap make_conf(*this);
+	read_make_conf(eprefixsource, &make_conf);
+	override_by_map(test_in_env_early, make_conf);
+}
+
+void PortageSettings::read_make_conf_late(const string& eprefixsource) {
+	string *useflags_profile(NULLPTR);
+	{
+		const_iterator it(find("USE"));
+		if(it != end()) {
+			useflags_profile = new string(it->second);
+			erase("USE");
+		}
+	}
+	read_make_conf(eprefixsource, this);
+	const char *useflags_make_conf = cstr("USE");
+	if(likely(useflags_make_conf != NULLPTR)) {
+		(*this)["USE.make_conf"] = useflags_make_conf;
+	}
+	if(unlikely(useflags_profile == NULLPTR)) {
+		return;
+	}
+	if(likely(useflags_make_conf != NULLPTR)) {
+		(*this)["USE"] = *useflags_profile + "\n" + useflags_make_conf;
+	} else {
+		(*this)["USE"] = *useflags_profile;
+	}
+	(*this)["USE.profile"] = *useflags_profile;
+	delete useflags_profile;
+}
+
+void PortageSettings::read_make_globals(const string& eprefixsource) {
+	const string& make_globals((*settings_rc)["MAKE_GLOBALS"]);
+	if(is_file(make_globals.c_str())) {
+		read_config(make_globals, eprefixsource);
+	} else {
+		read_config(m_eprefixconf + MAKE_GLOBALS_FILE, eprefixsource);
+	}
+}
+
+void PortageSettings::read_repos_conf(const string& eprefixsource) {
+	bool have_repos;
+	VarsReader reposfile(VarsReader::SUBST_VARS|VarsReader::PORTAGE_SECTIONS|VarsReader::RECURSE);
+	reposfile.setPrefix(eprefixsource);
+	string &repositories = (*this)["PORTAGE_REPOSITORIES"];
+	if(!repositories.empty()) {
+		const char *s = repositories.c_str();
+		have_repos = reposfile.readmem(s, s + repositories.size(), NULLPTR);
+	} else {
+		string errtext;
+		have_repos = reposfile.read((*settings_rc)["PORTAGE_REPOS_CONF"].c_str(), &errtext, true);
+		if(!have_repos) {
+			eix::say_error(_("error: %s")) % errtext;
+		}
+		if(reposfile.read((m_eprefixconf + USER_REPOS_CONF).c_str(), &errtext, true)) {
+			have_repos = true;
+		} else {
+			eix::say_error(_("error: %s")) % errtext;
+		}
+	}
+	const string *main_repo(NULLPTR);
+	OverlayIdent::Priority priority(-1000);
+	string& portdirref((*this)["PORTDIR"]);
+	if(likely(have_repos)) {
+		if(portdirref.empty()) {
+			main_repo = reposfile.find("main-repo");
+			const string *p(NULLPTR);
+			const string *prio(NULLPTR);
+			if(main_repo == NULLPTR) {
+				p = reposfile.find("location");
+				prio = reposfile.find("priority");
+			} else {
+				p = reposfile.find(string("location:") + *main_repo);
+				prio = reposfile.find(string("priority:") + *main_repo);
+			}
+			if(prio != NULLPTR) {
+				priority = my_atos(prio->c_str());
+			}
+			if(p != NULLPTR) {
+				portdirref = *p;
+			}
+		}
+	}
+	if(portdirref.empty()) {
+		portdirref = PORTDIR_DEFAULT;
+	}
+	/* Normalize "PORTDIR": */
+	portdirref = normalize_path((m_eprefixportdir + portdirref).c_str(), true, true);
+	add_repo(portdirref, false, (main_repo == NULLPTR) ? NULLPTR : main_repo->c_str(), priority, true);
+	/* Normalize overlays and erase duplicates */
+	string& ref((*this)["PORTDIR_OVERLAY"]);
+	{
+		WordVec portdir_overlayvec;
+		split_string(&portdir_overlayvec, ref, true);
+		add_repo_vector(portdir_overlayvec, true);
+	}
+	if(likely(have_repos)) {
+		string main_repo_check;
+		if(main_repo != NULLPTR) {
+			main_repo_check.assign(*main_repo);
+		}
+		for(VarsReader::const_iterator it(reposfile.begin());
+			likely(it != reposfile.end()); ++it) {
+			if(std::strncmp(it->first.c_str(), "location:", 9)) {
+				continue;
+			}
+			string label(it->first.substr(9));
+			if(unlikely(label == main_repo_check)) {
+				continue;
+			}
+			priority = 0;
+			const string *prio(reposfile.find(string("priority:") + label));
+			if(prio != NULLPTR) {
+				priority = my_atos(prio->c_str());
+			}
+			add_repo(it->second, true, label.c_str(), priority, false);
+		}
+	}
+	repos.sort();
+	WordVec overlayvec;
+	for(RepoList::const_iterator it(repos.second());
+		likely(it != repos.end()); ++it) {
+		overlayvec.PUSH_BACK(it->path);
+	}
+	ref.clear();
+	join_to_string(&ref, overlayvec, "\n");
+}
+
 string PortageSettings::resolve_overlay_name(const string& path, bool resolve) {
 	if(resolve) {
 		string full(m_eprefixoverlays);
@@ -205,110 +358,10 @@ void PortageSettings::init(EixRc *eixrc, const ParseError *e, bool getlocal, boo
 	(*this)["ARCH"]   = (*eixrc)["DEFAULT_ARCH"];
 
 	const string& eprefixsource((*eixrc)["EPREFIX_SOURCE"]);
-	const string& make_globals((*eixrc)["MAKE_GLOBALS"]);
-	if(is_file(make_globals.c_str())) {
-		read_config(make_globals, eprefixsource);
-	} else {
-		read_config(m_eprefixconf + MAKE_GLOBALS_FILE, eprefixsource);
-	}
-	read_config(m_eprefixconf + MAKE_CONF_FILE, eprefixsource);
-	read_config(m_eprefixconf + MAKE_CONF_FILE_NEW, eprefixsource);
-	string *use_make_conf; {
-		iterator it(find("USE"));
-		if(likely(it != end())) {
-			use_make_conf = new string(it->second);
-			erase(it);
-		} else {
-			use_make_conf = NULLPTR;
-		}
-	}
-
-	override_by_env(test_in_env_early); {
-		/* Read repos.conf */
-		bool have_repos;
-		VarsReader reposfile(VarsReader::SUBST_VARS|VarsReader::PORTAGE_SECTIONS|VarsReader::RECURSE);
-		reposfile.setPrefix(eprefixsource);
-		string &repositories = (*this)["PORTAGE_REPOSITORIES"];
-		if(!repositories.empty()) {
-			const char *s = repositories.c_str();
-			have_repos = reposfile.readmem(s, s + repositories.size(), NULLPTR);
-		} else {
-			string errtext;
-			have_repos = reposfile.read((*eixrc)["PORTAGE_REPOS_CONF"].c_str(), &errtext, true);
-			if(!have_repos) {
-				eix::say_error(_("error: %s")) % errtext;
-			}
-			if(reposfile.read((m_eprefixconf + USER_REPOS_CONF).c_str(), &errtext, true)) {
-				have_repos = true;
-			} else {
-				eix::say_error(_("error: %s")) % errtext;
-			}
-		}
-		const string *main_repo(NULLPTR);
-		OverlayIdent::Priority priority(-1000);
-		string& portdirref((*this)["PORTDIR"]);
-		if(likely(have_repos)) {
-			if(portdirref.empty()) {
-				main_repo = reposfile.find("main-repo");
-				const string *p(NULLPTR);
-				const string *prio(NULLPTR);
-				if(main_repo == NULLPTR) {
-					p = reposfile.find("location");
-					prio = reposfile.find("priority");
-				} else {
-					p = reposfile.find(string("location:") + *main_repo);
-					prio = reposfile.find(string("priority:") + *main_repo);
-				}
-				if(prio != NULLPTR) {
-					priority = my_atos(prio->c_str());
-				}
-				if(p != NULLPTR) {
-					portdirref = *p;
-				}
-			}
-		}
-		if(portdirref.empty()) {
-			portdirref = PORTDIR_DEFAULT;
-		}
-		/* Normalize "PORTDIR": */
-		portdirref = normalize_path((m_eprefixportdir + portdirref).c_str(), true, true);
-		add_repo(portdirref, false, (main_repo == NULLPTR) ? NULLPTR : main_repo->c_str(), priority, true);
-		/* Normalize overlays and erase duplicates */
-		string& ref((*this)["PORTDIR_OVERLAY"]);
-		WordVec overlayvec;
-		split_string(&overlayvec, ref, true);
-		add_repo_vector(overlayvec, true);
-		overlayvec.clear();
-		if(likely(have_repos)) {
-			string main_repo_check;
-			if(main_repo != NULLPTR) {
-				main_repo_check.assign(*main_repo);
-			}
-			for(VarsReader::const_iterator it(reposfile.begin());
-				likely(it != reposfile.end()); ++it) {
-				if(std::strncmp(it->first.c_str(), "location:", 9)) {
-					continue;
-				}
-				string label(it->first.substr(9));
-				if(unlikely(label == main_repo_check)) {
-					continue;
-				}
-				priority = 0;
-				const string *prio(reposfile.find(string("priority:") + label));
-				if(prio != NULLPTR) {
-					priority = my_atos(prio->c_str());
-				}
-				add_repo(it->second, true, label.c_str(), priority, false);
-			}
-		}
-		repos.sort();
-		for(RepoList::const_iterator it(repos.second());
-			likely(it != repos.end()); ++it) {
-			overlayvec.PUSH_BACK(it->path);
-		}
-		ref.clear();
-		join_to_string(&ref, overlayvec, "\n");
-	}
+	read_make_globals(eprefixsource);
+	read_make_conf_early(eprefixsource);
+	override_by_env(test_in_env_early);
+	read_repos_conf(eprefixsource);
 
 	user_config = NULLPTR;
 	profile = new CascadingProfile(this, init_world);
@@ -360,20 +413,9 @@ void PortageSettings::init(EixRc *eixrc, const ParseError *e, bool getlocal, boo
 		}
 	} else {
 		profile->readMakeDefaults();
-	} {
-		profile->readremoveFiles();
-		const char *useflags(cstr("USE"));
-		if(likely(useflags != NULLPTR)) {
-			(*this)["USE.profile"] = useflags;
-		}
-		if(likely(use_make_conf != NULLPTR)) {
-			(*this)["USE"] = *use_make_conf;
-			delete use_make_conf;
-		} else if(likely(useflags != NULLPTR)) {
-			erase("USE");
-		}
 	}
-
+	profile->readremoveFiles();
+	read_make_conf_late(eprefixsource);
 	override_by_env(test_in_env_late);
 
 	m_accepted_keywords.clear();
@@ -584,9 +626,6 @@ string PortageSettings::get_setnames(const Package *p, bool also_nonlocal) const
 	return join_to_string(names);
 }
 
-
-static CONSTEXPR const char *sets_exclude[] = { "..", "." , "system", "world", NULLPTR };
-
 void PortageSettings::read_local_sets(const WordVec& dir_list) {
 	world_setslist_up_to_date = false;
 	set_names.clear();
@@ -597,9 +636,12 @@ void PortageSettings::read_local_sets(const WordVec& dir_list) {
 	all_set_names is used as a cache to find duplicate set names faster
 	**/
 	WordUnorderedSet all_set_names;
+	// We ignore these sets, as they are filled differently:
+	all_set_names.INSERT("system");
+	all_set_names.INSERT("world");
 	for(WordVec::size_type i(0); likely(i != dir_list.size()); ++i) {
 		WordVec temporary_set_names;
-		pushback_files(dir_list[i], &temporary_set_names, sets_exclude, 0, true, false);
+		pushback_files_recurse(dir_list[i], &temporary_set_names, false, NULLPTR);
 		WordVec::size_type s(set_names.size());
 		// Avoid duplicate sets
 		for(WordVec::const_iterator it(temporary_set_names.begin());
@@ -618,7 +660,7 @@ void PortageSettings::read_local_sets(const WordVec& dir_list) {
 		string dir_slash(dir_list[i]);
 		optional_append(&dir_slash, '/');
 		for(WordVec::size_type j(0); likely(j != dir_size[i]); ++j) {
-			grab_setmasks((dir_slash + set_names[c]).c_str(), c, &(child_names[c]));
+			grab_setmasks((dir_slash + set_names[c]).c_str(), c, &(child_names[c]), false);
 			++c;
 		}
 	}
