@@ -198,8 +198,19 @@ class PortageSettings : public WordIterateMap {
 		**/
 		CascadingProfile  *profile;
 
+		ATTRIBUTE_NONNULL_ void override_by_map(const char *const *vars, const WordIterateMap& varmap);
 		ATTRIBUTE_NONNULL_ void override_by_env(const char *const *vars);
-		void read_config(const std::string& name, const std::string& prefix);
+		ATTRIBUTE_NONNULL_ void override_by_value(const char *var, const std::string& value);
+		ATTRIBUTE_NONNULL((2)) void override_by_value(const char *var, const char *value);
+		ATTRIBUTE_NONNULL_ void read_config(const std::string& name, const std::string& prefix, WordIterateMap *vars);
+		void read_config(const std::string& name, const std::string& prefix) {
+			read_config(name, prefix, this);
+		}
+		ATTRIBUTE_NONNULL_ void read_make_conf(const std::string& eprefixsource, WordIterateMap *vars);
+		void read_make_conf_early(const std::string& eprefixsource);
+		void read_make_conf_late(const std::string& eprefixsource);
+		void read_make_globals(const std::string& eprefixsource);
+		void read_repos_conf(const std::string& eprefixsource);
 
 		ATTRIBUTE_NONNULL_ void addOverlayProfiles(CascadingProfile *p) const;
 
@@ -211,9 +222,6 @@ class PortageSettings : public WordIterateMap {
 		void update_world_setslist();
 
 		bool grab_setmasks(const char *file, SetsIndex i, WordVec *contains_set, bool recursive);
-		bool grab_setmasks(const char *file, SetsIndex i, WordVec *contains_set) {
-			return grab_setmasks(file, i, contains_set, false);
-		}
 
 		const MaskList<SetMask> *getPackageSets() const {
 			return &m_package_sets;
@@ -241,6 +249,7 @@ class PortageSettings : public WordIterateMap {
 #endif
 		using WordIterateMap::find;
 		using WordIterateMap::erase;
+		using WordIterateMap::begin;
 		using WordIterateMap::end;
 		using WordIterateMap::operator[];
 
