@@ -6,7 +6,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "portage/instversion.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include "eixTk/eixint.h"
 #include "eixTk/likely.h"
