@@ -10,7 +10,7 @@
 #ifndef SRC_PORTAGE_PACKAGESETS_H_
 #define SRC_PORTAGE_PACKAGESETS_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <vector>
 #include <string>
