@@ -28,6 +28,7 @@
 #include "portage/basicversion.h"
 #include "portage/extendedversion.h"
 #include "portage/instversion.h"
+#include "portage/version.h"
 
 using std::string;
 
@@ -250,15 +251,21 @@ bool VarDbPkg::readUse(const Package& p, InstVersion *v) const {
 		}
 		join_and_split(&alluse, lines);
 	}
+
+	IUseSet iuse_set;
 	for(WordVec::iterator it(inst_iuse.begin());
 		it != inst_iuse.end(); ++it) {
 		while(((*it)[0] == '+') || ((*it)[0] == '-')) {
 			it->erase(0, 1);
 		}
+		iuse_set.insert_fast(*it);
+	}
+	IUseSet::IUseNaturalOrder ordered(iuse_set.asNaturalOrder());
+	inst_iuse.clear();
+	for(IUseSet::IUseNaturalOrder::const_iterator it(ordered.begin());
+		it != ordered.end(); ++it) {
+		inst_iuse.PUSH_BACK(MOVE(it->name()));
 	}
-	// Sort words and provide hash
-	WordSet iuse_set(inst_iuse.begin(), inst_iuse.end());
-	inst_iuse = WordVec(iuse_set.begin(), iuse_set.end());
 
 	for(WordVec::iterator it(alluse.begin());
 		it != alluse.end(); ++it) {
@@ -267,9 +274,10 @@ bool VarDbPkg::readUse(const Package& p, InstVersion *v) const {
 		}
 	}
 
+	IUseSet::IUseStd iuse_std(iuse_set.asStd());
 	for(WordVec::iterator it(alluse.begin());
 		likely(it != alluse.end()); ++it) {
-		if(iuse_set.count(*it) != 0) {
+		if(iuse_std.count(IUse(*it)) != 0) {
 			v->usedUse.INSERT(MOVE(*it));
 		}
 	}
@@ -347,18 +355,20 @@ void VarDbPkg::readDepend(const Package& p, InstVersion *v, const DBHeader& head
 	}
 	v->depend.clear();
 	string dirname(m_directory + p.category + "/" + p.name + "-" + v->getFull());
-	WordVec depend(4);
+	WordVec depend(5);
 	depend[0] = v->depend.get_depend();
 	depend[1] = v->depend.get_rdepend();
 	depend[2] = v->depend.get_pdepend();
 	depend[3] = v->depend.get_bdepend();
-	static CONSTEXPR const char *filenames[4] = {
+	depend[4] = v->depend.get_idepend();
+	static CONSTEXPR const char *filenames[5] = {
 		"/DEPEND",
 		"/RDEPEND",
 		"/PDEPEND",
-		"/BDEPEND"
+		"/BDEPEND",
+		"/IDEPEND"
 	};
-	for(eix::TinyUnsigned i(0); likely(i < 4); ++i) {
+	for(eix::TinyUnsigned i(0); likely(i < 5); ++i) {
 		LineVec lines;
 		if(likely(pushback_lines((dirname + filenames[i]).c_str(),
 			&lines, false, false, 1))) {
@@ -370,7 +380,7 @@ void VarDbPkg::readDepend(const Package& p, InstVersion *v, const DBHeader& head
 			}
 		}
 	}
-	v->depend.set(depend[0], depend[1], depend[2], depend[3], true);
+	v->depend.set(depend[0], depend[1], depend[2], depend[3], depend[4], true);
 }
 
 /**
