@@ -9,18 +9,20 @@
 #ifndef SRC_SEARCH_LEVENSHTEIN_H_
 #define SRC_SEARCH_LEVENSHTEIN_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
+
+#include <sys/types.h>
 
 #include "eixTk/attribute.h"
 
-typedef unsigned int Levenshtein;
+typedef size_t Levenshtein;
 
 /**
 Calculates the Levenshtein distance of two strings.
 Reference: http://www.merriampark.com/ld.htm
 @param str_a string a
 @param str_b string b
-@return unsigned int Levenshtein distance of str_a <> str_b
+@return Levenshtein distance of strings a and b
 **/
 ATTRIBUTE_NONNULL_ ATTRIBUTE_PURE Levenshtein get_levenshtein_distance(const char *str_a, const char *str_b);
 
