@@ -128,6 +128,8 @@ static void init_match_field_map() {
 	match_field_map["pdepend"]        = PackageTest::PDEPEND;
 	match_field_map["BDEPEND"]        = PackageTest::BDEPEND;
 	match_field_map["bdepend"]        = PackageTest::BDEPEND;
+	match_field_map["IDEPEND"]        = PackageTest::IDEPEND;
+	match_field_map["idepend"]        = PackageTest::IDEPEND;
 	match_field_map["ERROR"]          = PackageTest::NONE;
 	match_field_map["error"]          = PackageTest::NONE;
 }
@@ -209,6 +211,10 @@ static void init_match_algorithm_map() {
 	match_algorithm_map["REGEXP"]     = PackageTest::ALGO_REGEX;
 	match_algorithm_map["regex"]      = PackageTest::ALGO_REGEX;
 	match_algorithm_map["regexp"]     = PackageTest::ALGO_REGEX;
+	match_algorithm_map["REGEXCASE"]  = PackageTest::ALGO_REGEXCASE;
+	match_algorithm_map["REGEXPCASE"] = PackageTest::ALGO_REGEXCASE;
+	match_algorithm_map["regexcase"]  = PackageTest::ALGO_REGEXCASE;
+	match_algorithm_map["regexpcase"] = PackageTest::ALGO_REGEXCASE;
 	match_algorithm_map["EXACT"]      = PackageTest::ALGO_EXACT;
 	match_algorithm_map["exact"]      = PackageTest::ALGO_EXACT;
 	match_algorithm_map["BEGIN"]      = PackageTest::ALGO_BEGIN;
@@ -363,6 +369,9 @@ void PackageTest::setAlgorithm(MatchAlgorithm a) {
 		case ALGO_REGEX:
 			setAlgorithm(new RegexAlgorithm());
 			break;
+		case ALGO_REGEXCASE:
+			setAlgorithm(new RegexCaseAlgorithm());
+			break;
 		case ALGO_EXACT:
 			setAlgorithm(new ExactAlgorithm());
 			break;
