@@ -10,7 +10,7 @@
 #ifndef SRC_SEARCH_REDUNDANCY_H_
 #define SRC_SEARCH_REDUNDANCY_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include "portage/keywords.h"
 
