@@ -115,21 +115,25 @@ enum cli_options {
 	O_SEARCH_INST_SLOT,
 	O_SEARCH_INST_FULLSLOT,
 	O_SEARCH_SET,
+	O_REGEX_CASE,
 	O_END_ALGO,
 	O_DEPEND,
 	O_RDEPEND,
 	O_PDEPEND,
 	O_BDEPEND,
+	O_IDEPEND,
 	O_DEPS,
 	O_AVAILABLE_DEPEND,
 	O_AVAILABLE_RDEPEND,
 	O_AVAILABLE_PDEPEND,
 	O_AVAILABLE_BDEPEND,
+	O_AVAILABLE_IDEPEND,
 	O_AVAILABLE_DEPS,
 	O_INSTALLED_DEPEND,
 	O_INSTALLED_RDEPEND,
 	O_INSTALLED_PDEPEND,
 	O_INSTALLED_BDEPEND,
+	O_INSTALLED_IDEPEND,
 	O_INSTALLED_DEPS,
 	O_RESTRICT_FETCH,
 	O_RESTRICT_MIRROR,
