@@ -8,7 +8,7 @@
 #ifndef SRC_VARIOUS_DROP_PERMISSIONS_H_
 #define SRC_VARIOUS_DROP_PERMISSIONS_H_ 1
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
